.. Django Courier documentation master file, created by
   sphinx-quickstart on Sun Mar 18 17:38:19 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
.. TODO: support genindex and modindex

Django Courier Documentation
============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   getting_started
   backends
   protocols
   templates
   demo
   comparison


Indices and tables
==================

* :ref:`search`
